class ProblemWithFetchNumbers(Exception):
    """Problem with fetch phone numbers"""


class ProblemWithFetchMessages(Exception):
    """Problem with fetch messages"""


class ProblemWithCounties(Exception):
    """Problem with fetch counties"""


class NoNumbers(Exception):
    """Not found numbers"""


class NoCountyFound(Exception):
    """No specific country found"""
